@@ -81,16 +81,18 @@ sub config {
     return $res;
   }
   elsif (my $cb = $cb[0]) {
-    $self->_redis->_execute(basic => CONFIG => GET => $key => sub {
-      my ($redis, $err, $params) = @_;
-      $params //= [];
-      $_[0]->$cb($err, $key =~ /\*/ ? { @$params } : $params->[1]);
-    });
+    $self->_redis->_execute(
+      basic => CONFIG => GET => $key => sub {
+        my ($redis, $err, $params) = @_;
+        $params //= [];
+        $_[0]->$cb($err, $key =~ /\*/ ? {@$params} : $params->[1]);
+      }
+    );
     return $self;
   }
   else {
     my $params = $self->_redis->_execute(basic => CONFIG => GET => $key);
-    return $key =~ /\*/ ? { @$params } : $params->[1];
+    return $key =~ /\*/ ? {@$params} : $params->[1];
   }
 }
 
@@ -133,19 +135,21 @@ C<$section> is "clients":
 =cut
 
 sub info {
-  my $cb = ref $_[-1] eq 'CODE' ? pop : undef;
-  my $self = shift;
+  my $cb      = ref $_[-1] eq 'CODE' ? pop : undef;
+  my $self    = shift;
   my $section = shift || '';
 
   if ($cb) {
-    $self->_redis->_execute(basic => INFO => $section => sub {
-      $_[0]->$cb($_[1], { map { split /:/, $_, 2 } grep { /:/ } split /\r\n/, $_[2] // '' });
-    });
+    $self->_redis->_execute(
+      basic => INFO => $section => sub {
+        $_[0]->$cb($_[1], {map { split /:/, $_, 2 } grep {/:/} split /\r\n/, $_[2] // ''});
+      }
+    );
     return $self;
   }
   else {
     my $text = $self->_redis->_execute(basic => INFO => $section);
-    return { map { split /:/, $_, 2 } grep { /:/ } split /\r\n/, $text };
+    return {map { split /:/, $_, 2 } grep {/:/} split /\r\n/, $text};
   }
 }
 
@@ -191,12 +195,16 @@ format as L<Time::Hires/gettimeofday> in an array-ref:
 
 for my $method (qw( resetstat rewrite )) {
   my $op = uc $method;
-  eval "sub $method { my \$self = shift; my \$r = \$self->_redis->_execute(basic => CONFIG => $op => \@_); return \@_ ? \$self : \$r }; 1" or die $@;
+  eval
+    "sub $method { my \$self = shift; my \$r = \$self->_redis->_execute(basic => CONFIG => $op => \@_); return \@_ ? \$self : \$r }; 1"
+    or die $@;
 }
 
 for my $method (qw( bgrewriteaof bgsave dbsize flushall flushdb lastsave save time )) {
   my $op = uc $method;
-  eval "sub $method { my \$self = shift; my \$r = \$self->_redis->_execute(basic => $op => \@_); return \@_ ? \$self : \$r }; 1" or die $@;
+  eval
+    "sub $method { my \$self = shift; my \$r = \$self->_redis->_execute(basic => $op => \@_); return \@_ ? \$self : \$r }; 1"
+    or die $@;
 }
 
 =head1 COPYRIGHT AND LICENSE
